@@ -131,7 +131,7 @@ let seq ~(sep:doc)  ~(doit:'a -> doc) ~(elements: 'a list) =
       let fh = doit h in loop fh t)
 
 
-let docArray (sep:doc) (doit:int -> 'a -> doc) () (elements:'a array) = 
+let docArray ?(sep=chr ',') (doit:int -> 'a -> doc) () (elements:'a array) = 
   let len = Array.length elements in
   if len = 0 then 
     nil
@@ -150,7 +150,7 @@ let docOpt delem () = function
 
 
 
-let docList (sep:doc) (doit:'a -> doc) () (elements:'a list) = 
+let docList ?(sep=chr ',') (doit:'a -> doc) () (elements:'a list) = 
   seq sep doit elements
 
 let insert () d = d
@@ -160,7 +160,25 @@ let d_list (sep:string) (doit:unit -> 'a -> doc) () (elts:'a list) : doc =
   (* thunk 'doit' to match docList's interface *)
   let internalDoit (elt:'a) =
     (doit () elt) in
-  (docList (text sep) internalDoit () elts)
+  (docList ~sep:(text sep) internalDoit () elts)
+
+(** Format maps *)
+module MakeMapPrinter = functor (Map: Map.S) -> struct
+  let docMap ?(sep=chr ',')
+              (doit: Map.key -> 'a -> doc) () (maplets: 'a Map.t) : doc =
+    Map.fold
+      (fun k d acc ->
+	(if acc==nil then acc else acc ++ sep)
+	  ++ (doit k d))
+      maplets
+      nil
+
+  let dmaplet d0 d1 = d0 ++ (text " |-> ") ++ d1
+
+  let d_map ?(dmaplet=dmaplet) (sep:string) dkey dval =
+    let doit = fun k d -> dmaplet (dkey () k) (dval () d) in
+    docMap ~sep:(text sep) doit
+end
 
 
 (******************************************************************************)	
@@ -567,8 +585,8 @@ let sprint ~(width : int)  doc : string =
 
 
                                         (* The rest is based on printf.ml *)
-external format_int: string -> int -> string = "format_int"
-external format_float: string -> float -> string = "format_float"
+external format_int: string -> int -> string = "caml_format_int"
+external format_float: string -> float -> string = "caml_format_float"
 
 
     
@@ -689,7 +707,7 @@ let gprintf (finish : doc -> doc)
               collect (dctext1 acc
                          (format_float (String.sub format i (j-i+1)) f))
                 (succ j))
-        | 'b' ->
+        | 'b' | 'B' ->
             Obj.magic(fun b ->
               collect (dctext1 acc (string_of_bool b)) (succ j))
         | 'a' ->
