@@ -138,14 +138,6 @@ val tryFinally:
     'a -> 'b
 
 
-(** The state information that the UI must display is viewed abstractly as a 
- * set of registers. *)
-type registerInfo = {
-    rName: string; (** The name of the register *)
-    rGroup: string; (** The name of the group to which this register belongs.*)
-    rVal: Pretty.doc; (** The value to be displayed about a register *)
-    rOneLineVal: Pretty.doc option (** The value to be displayed on one line *)
-} 
 
 
 (** Get the value of an option.  Raises Failure if None *)
@@ -263,7 +255,8 @@ val registerSymbolName: string -> symbol
 
 (** Register a number of consecutive symbol ids. The naming function will be 
  * invoked with indices from 0 to the counter - 1. Returns the id of the 
- * first symbol created *)
+ * first symbol created. The naming function is invoked lazily, only when the 
+ * name of the symbol is required. *)
 val registerSymbolRange: int -> (int -> string) -> symbol
 
 
