@@ -46,6 +46,7 @@ module P = Pretty
 open Cil
 module E = Errormsg
 module H = Hashtbl
+module A = Alpha
 open Trace
 
 let debugMerge = false
@@ -315,13 +316,16 @@ let inlineBodies : (P.doc, varinfo node) H.t = H.create 111
  * name space. Unfortunately, because of the way the C lexer works, type 
  * names must be different from variable names!! We one alpha table both for 
  * variables and types. *)
-let vtAlpha : (string, alphaTableData ref) H.t = H.create 57 (* Variables and 
+let vtAlpha : (string, location A.alphaTableData ref) H.t 
+    = H.create 57 (* Variables and 
                                                              * types *)
-let sAlpha : (string, alphaTableData ref) H.t = H.create 57 (* Structures and 
+let sAlpha : (string, location A.alphaTableData ref) H.t 
+    = H.create 57 (* Structures and 
                                                              * unions have 
                                                              * the same name 
                                                              * space *)
-let eAlpha : (string, alphaTableData ref) H.t = H.create 57 (* Enumerations *)
+let eAlpha : (string, location A.alphaTableData ref) H.t 
+    = H.create 57 (* Enumerations *)
 
 
 (** Keep track, for all global function definitions, of the names of the formal 
@@ -775,7 +779,7 @@ let rec oneFilePass1 (f:file) : unit =
    * with the same name have been encountered before and we merge those types 
    * *)
   let matchVarinfo (vi: varinfo) (l: location * int) = 
-    ignore (registerAlphaName vtAlpha None vi.vname);
+    ignore (Alpha.registerAlphaName vtAlpha None vi.vname !currentLoc);
     (* Make a node for it and put it in vEq *)
     let vinode = mkSelfNode vEq vSyn !currentFidx vi.vname vi (Some l) in
     try
@@ -1306,13 +1310,13 @@ let oneFilePass2 (f: file) =
       else begin
         (* Maybe it is static. Rename it then *)
         if vi.vstorage = Static then begin
-          let newName, _ = newAlphaName vtAlpha None vi.vname in
+          let newName, _ = A.newAlphaName vtAlpha None vi.vname !currentLoc in
           (* Remember the original name *)
           H.add originalVarNames newName vi.vname;
           if debugMerge then ignore (E.log "renaming %s at %a to %s\n"
                                            vi.vname d_loc vloc newName);
           vi.vname <- newName;
-          vi.vid <- H.hash vi.vname;
+          vi.vid <- newVID ();
           vi.vreferenced <- true;
           vi
         end else begin
@@ -1568,7 +1572,8 @@ let oneFilePass2 (f: file) =
                   E.s (bug "Setting creferenced for struct %s(%d) which is not in the sEq!\n"
                          ci.cname !currentFidx);
                 end);
-                let newname, _ = newAlphaName sAlpha None ci.cname in
+                let newname, _ = 
+                  A.newAlphaName sAlpha None ci.cname !currentLoc in
                 ci.cname <- newname;
                 ci.creferenced <- true; 
                 ci.ckey <- H.hash (compFullName ci);
@@ -1591,7 +1596,8 @@ let oneFilePass2 (f: file) =
           else begin
             match findReplacement true eEq !currentFidx ei.ename with 
               None -> (* We must rename it *)
-                let newname, _ = newAlphaName eAlpha None ei.ename in
+                let newname, _ = 
+                  A.newAlphaName eAlpha None ei.ename !currentLoc in
                 ei.ename <- newname;
                 ei.ereferenced <- true;
                 (* And we must rename the items to using the same name space 
@@ -1599,7 +1605,8 @@ let oneFilePass2 (f: file) =
                 ei.eitems <- 
                    List.map
                      (fun (n, i, loc) -> 
-                       let newname, _ = newAlphaName vtAlpha None n in
+                       let newname, _ = 
+                         A.newAlphaName vtAlpha None n !currentLoc in
                        newname, i, loc)
                      ei.eitems;
                 mergePushGlobals (visitCilGlobal renameVisitor g);
@@ -1639,7 +1646,8 @@ let oneFilePass2 (f: file) =
           else begin
             match findReplacement true tEq !currentFidx ti.tname with 
               None -> (* We must rename it and keep it *)
-                let newname, _ = newAlphaName vtAlpha None ti.tname in
+                let newname, _ = 
+                  A.newAlphaName vtAlpha None ti.tname !currentLoc in
                 ti.tname <- newname;
                 ti.treferenced <- true;
                 mergePushGlobals (visitCilGlobal renameVisitor g);
